TempUtils class

Utilidades temporales para romper la dependencia circular Estas funciones serán reemplazadas cuando se publique flutter_utils_providers

Constructors

TempUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

convertFromISODate(String isoDate) String
Convierte una fecha ISO a formato de fecha (dd/MM/yyyy)
convertFromISODateTime(String isoDate) String
Convierte una fecha ISO a formato de fecha y hora (dd/MM/yyyy HH:mm)
logDebug(String message) → void
Imprime un mensaje de debug